searchData={"content_type":"text/markdown","items":[{"doc":"To use HareMq in your Elixir project, follow these steps:\n\nInstall the required dependencies by adding them to your `mix.exs` file:\n\n```elixir\ndefp deps do\n[\n  {:hare_mq, \"~> 1.1.0\"}\n]\nend\n```","ref":"HareMq.html","title":"HareMq","type":"module"},{"doc":"The `MyApp.MessageProducer` module is responsible for publishing messages to a message queue using the `HareMq.Publisher` behavior. This module provides an interface for sending messages with specified routing and exchange settings. It also supports deduplication based on specific keys.\n\nThe `MyApp.MessageProducer` module is configured with the following options:\n\n- **`routing_key`**: Specifies the routing key used to route messages to the appropriate queue. In this example, the routing key is set to `\"routing_key\"`.\n\n- **`exchange`**: Defines the exchange to which messages will be published. In this example, the exchange is set to `\"exchange\"`.\n\n- **`unique`**: This configuration option sets up deduplication rules:\n- **`period`**: Defines the time period for deduplication in ms. In this example, it is set to `:infinity`, meaning that messages are considered unique indefinitely based on the specified keys.\n- **`keys`**: A list of keys used to determine message uniqueness. In this example, deduplication is based on the `:project_id` key.\n\n\n```elixir\ndefmodule MyApp.MessageProducer do\nuse HareMq.Publisher,\n  routing_key: \"routing_key\",\n  exchange: \"exchange\"\n\n# Function to send a message to the message queue.\ndef send_message(message) do\n  # Publish the message using the HareMq.Publisher behavior.\n  publish_message(message)\nend\nend\n```\n\n```elixir\ndefmodule MyApp.MessageProducer do\nuse HareMq.Publisher,\n  routing_key: \"routing_key\",\n  exchange: \"exchange\",\n  unique: [\n    period: :infinity,\n    keys: [:project_id]\n  ]\n\n# Function to send a message to the message queue.\ndef send_message(message) do\n  # Publish the message using the HareMq.Publisher behavior.\n  publish_message(message)\nend\nend\n```","ref":"HareMq.html#module-publisher","title":"Publisher - HareMq","type":"module"},{"doc":"The `MyApp.MessageConsumer` module is designed to consume messages from a message queue using the `HareMq.Consumer` behavior. This module provides the functionality to receive and process messages with specific routing and exchange settings.\n\nThe `MyApp.MessageConsumer` module is configured with the following options:\n\n- **`queue_name`**: Specifies the name of the queue from which messages will be consumed. In this example, the queue name is set to `\"queue_name\"`.\n\n- **`routing_key`**: Defines the routing key used to filter messages. In this example, the routing key is set to `\"routing_key\"`.\n\n- **`exchange`**: Defines the exchange from which messages will be consumed. In this example, the exchange is set to `\"exchange\"`.\n\n```elixir\ndefmodule MyApp.MessageConsumer do\nuse HareMq.Consumer,\n  queue_name: \"queue_name\",\n  routing_key: \"routing_key\",\n  exchange: \"exchange\"\n\n# Function to process a received message.\ndef consume(message) do\n  # Log the beginning of the message processing.\n  IO.puts(\"Processing message: #{inspect(message)}\")\nend\nend\n```","ref":"HareMq.html#module-consumer","title":"Consumer - HareMq","type":"module"},{"doc":"The `MyApp.MessageConsumer` module is designed to consume messages from a message queue using the `HareMq.DynamicConsumer` behavior. This module provides the functionality to receive and process messages with dynamic scaling based on the specified number of worker processes.\n\nThe `MyApp.MessageConsumer` module is configured with the following options:\n\n- **`queue_name`**: Specifies the name of the queue from which messages will be consumed. In this example, the queue name is set to `\"queue_name\"`.\n\n- **`routing_key`**: Defines the routing key used to filter messages. In this example, the routing key is set to `\"routing_key\"`.\n\n- **`exchange`**: Defines the exchange from which messages will be consumed. In this example, the exchange is set to `\"exchange\"`.\n\n- **`consumer_count`**: Indicates the number of worker processes that should be used to handle incoming messages. In this example, `consumer_count` is set to `10`, which means that 10 worker processes will be run to consume and process messages concurrently.\n\n\n```elixir\ndefmodule MyApp.MessageConsumer do\nuse HareMq.DynamicConsumer,\n  queue_name: \"queue_name\",\n  routing_key: \"routing_key\",\n  exchange: \"exchange\",\n  consumer_count: 10\n\n# Function to process a received message.\ndef consume(message) do\n  # Log the beginning of the message processing.\n  IO.puts(\"Processing message: #{inspect(message)}\")\nend\nend\n```","ref":"HareMq.html#module-dynamic-consumer","title":"Dynamic Consumer - HareMq","type":"module"},{"doc":"```elixir\ndefmodule MyApp.Application do\nuse Application\n\ndef start(_type, _args) do\n  children = [\n    # Start the message consumer.\n    MyApp.MessageConsumer,\n\n    # Start the message producer.\n    MyApp.MessageProducer,\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\nend\n```","ref":"HareMq.html#module-usage-in-application-myapp-application","title":"Usage in Application: MyApp.Application - HareMq","type":"module"},{"doc":"```elixir\nconfig :hare_mq,\n:amqp,\n  host: \"localhost\",\n  url: \"amqp://guest:guest@myhost:12345\",\n  user: \"guest\",\n  password: \"guest\"\n\nconfig :hare_mq, :configuration,\ndelay_in_ms: 10_000,\nretry_limit: 15,\nmessage_ttl: 31_449_600\n```","ref":"HareMq.html#module-configuration","title":"Configuration - HareMq","type":"module"},{"doc":"If you enjoy using HareMq, please consider giving us a star on GitHub! Your feedback and support are highly appreciated.\n[GitHub](https://github.com/Dimakoua/hare_mq)","ref":"HareMq.html#module-rate-us","title":"Rate Us: - HareMq","type":"module"},{"doc":"","ref":"HareMq.html#start/2","title":"HareMq.start/2","type":"function"},{"doc":"Configuration module for HareMq.\n\nThis module provides functions for configuring HareMq components, such as queues and connections.","ref":"HareMq.Configuration.html","title":"HareMq.Configuration","type":"module"},{"doc":"Structure representing the configuration for a queue.","ref":"HareMq.Configuration.html#__struct__/0","title":"HareMq.Configuration.__struct__/0","type":"function"},{"doc":"- `:channel`: The AMQP channel.\n- `:queue_name`: The name of the queue.\n- `:delay_queue_name`: The name of the delay queue.\n- `:dead_queue_name`: The name of the dead letter queue.\n- `:exchange`: The AMQP exchange.\n- `:routing_key`: The routing key.\n- `:delay_in_ms`: The delay in milliseconds.\n- `:message_ttl`: The message time-to-live.\n- `:retry_limit`: The number of retry attempts.\n- `:durable`: Whether the queue is durable or not.","ref":"HareMq.Configuration.html#__struct__/0-fields","title":"Fields - HareMq.Configuration.__struct__/0","type":"function"},{"doc":"config = %Configuration{...}","ref":"HareMq.Configuration.html#__struct__/0-examples","title":"Examples - HareMq.Configuration.__struct__/0","type":"function"},{"doc":"Get the configuration for a queue.","ref":"HareMq.Configuration.html#get_queue_configuration/1","title":"HareMq.Configuration.get_queue_configuration/1","type":"function"},{"doc":"config = get_queue_configuration(\n      channel: channel,\n      name: name,\n      exchange: exchange,\n      routing_key: routing_key\n    )","ref":"HareMq.Configuration.html#get_queue_configuration/1-examples","title":"Examples - HareMq.Configuration.get_queue_configuration/1","type":"function"},{"doc":"GenServer module for managing AMQP connection.\n\nThis module handles the lifecycle of the AMQP connection and provides functions for getting, closing, and monitoring the connection.","ref":"HareMq.Connection.html","title":"HareMq.Connection","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"HareMq.Connection.html#child_spec/1","title":"HareMq.Connection.child_spec/1","type":"function"},{"doc":"Close the current connection.\n\nReturns:\n  - `{:ok, connection}`: If the connection is successfully closed.\n  - `{:error, :not_connected}`: If the connection is not established.","ref":"HareMq.Connection.html#close_connection/0","title":"HareMq.Connection.close_connection/0","type":"function"},{"doc":"case HareMq.Connection.close_connection() do\n      {:ok, conn} -> IO.inspect(conn)\n      {:error, :not_connected} -> IO.puts(\"Not connected!\")\n    end","ref":"HareMq.Connection.html#close_connection/0-examples","title":"Examples - HareMq.Connection.close_connection/0","type":"function"},{"doc":"Get the current connection.\n\nReturns:\n  - `{:ok, connection}`: If the connection is established.\n  - `{:error, :not_connected}`: If the connection is not established.","ref":"HareMq.Connection.html#get_connection/0","title":"HareMq.Connection.get_connection/0","type":"function"},{"doc":"case HareMq.Connection.get_connection() do\n      {:ok, conn} -> IO.inspect(conn)\n      {:error, :not_connected} -> IO.puts(\"Not connected!\")\n    end","ref":"HareMq.Connection.html#get_connection/0-examples","title":"Examples - HareMq.Connection.get_connection/0","type":"function"},{"doc":"","ref":"HareMq.Connection.html#init/1","title":"HareMq.Connection.init/1","type":"function"},{"doc":"","ref":"HareMq.Connection.html#start_link/1","title":"HareMq.Connection.start_link/1","type":"function"},{"doc":"GenServer module implementing a RabbitMQ consumer.\n\nThis module provides a behavior for RabbitMQ message consumption, including connecting to RabbitMQ, declaring queues, and handling incoming messages.","ref":"HareMq.Consumer.html","title":"HareMq.Consumer","type":"module"},{"doc":"","ref":"HareMq.Consumer.Behaviour.html","title":"HareMq.Consumer.Behaviour","type":"behaviour"},{"doc":"","ref":"HareMq.Consumer.Behaviour.html#c:consume/1","title":"HareMq.Consumer.Behaviour.consume/1","type":"callback"},{"doc":"A GenServer-based cache for message deduplication in a RabbitMQ system.","ref":"HareMq.DedupCache.html","title":"HareMq.DedupCache","type":"module"},{"doc":"The `HareMq.DedupCache` module provides functionality to manage a cache of messages to prevent\nthe processing of duplicate messages. It uses a GenServer to store messages along with their\nexpiration timestamps and supports deduplication based on specific keys within a message.","ref":"HareMq.DedupCache.html#module-overview","title":"Overview - HareMq.DedupCache","type":"module"},{"doc":"- **Deduplication:** Checks if a message is a duplicate based on its content and optional deduplication keys.\n- **TTL Management:** Allows setting a time-to-live (TTL) for cached messages. Messages can be set to expire after a certain time or remain in the cache indefinitely.\n- **Automatic Cache Clearing:** Periodically clears expired messages from the cache.","ref":"HareMq.DedupCache.html#module-features","title":"Features - HareMq.DedupCache","type":"module"},{"doc":"- `is_dup?/2`: Checks if a given message is a duplicate based on the cache.\n- `add/3`: Adds a message to the cache with a specified TTL.","ref":"HareMq.DedupCache.html#module-functions","title":"Functions - HareMq.DedupCache","type":"module"},{"doc":"This module is intended for use in systems where message deduplication is required, such as in RabbitMQ consumers\nwhere the same message might be delivered multiple times. The cache ensures that duplicate messages are identified\nand not processed multiple times.","ref":"HareMq.DedupCache.html#module-usage","title":"Usage - HareMq.DedupCache","type":"module"},{"doc":"","ref":"HareMq.DedupCache.html#add/3","title":"HareMq.DedupCache.add/3","type":"function"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"HareMq.DedupCache.html#child_spec/1","title":"HareMq.DedupCache.child_spec/1","type":"function"},{"doc":"","ref":"HareMq.DedupCache.html#init/1","title":"HareMq.DedupCache.init/1","type":"function"},{"doc":"","ref":"HareMq.DedupCache.html#is_dup?/2","title":"HareMq.DedupCache.is_dup?/2","type":"function"},{"doc":"","ref":"HareMq.DedupCache.html#start_link/1","title":"HareMq.DedupCache.start_link/1","type":"function"},{"doc":"This module provides a dynamic supervisor for managing worker processes in the HareMq application.\nIt is designed to start a configurable number of consumer processes to handle message consumption.","ref":"HareMq.DynamicConsumer.html","title":"HareMq.DynamicConsumer","type":"module"},{"doc":"","ref":"HareMq.DynamicConsumer.Behaviour.html","title":"HareMq.DynamicConsumer.Behaviour","type":"behaviour"},{"doc":"","ref":"HareMq.DynamicConsumer.Behaviour.html#c:consume/1","title":"HareMq.DynamicConsumer.Behaviour.consume/1","type":"callback"},{"doc":"","ref":"HareMq.DynamicSupervisor.html","title":"HareMq.DynamicSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"HareMq.DynamicSupervisor.html#child_spec/1","title":"HareMq.DynamicSupervisor.child_spec/1","type":"function"},{"doc":"Initializes the dynamic supervisor with the specified options.\n\nIt starts a Task to asynchronously run the start_consumers function and initializes\nthe dynamic supervisor with a one_for_one restart strategy.","ref":"HareMq.DynamicSupervisor.html#init/1","title":"HareMq.DynamicSupervisor.init/1","type":"function"},{"doc":"iex> HareMq.DynamicSupervisor.start_link([config: %{consumer_count: 3}, consume: MyApp.Consumer])\n    {:ok, #PID<0.123.0>}","ref":"HareMq.DynamicSupervisor.html#init/1-examples","title":"Examples - HareMq.DynamicSupervisor.init/1","type":"function"},{"doc":"Starts a child worker process with the specified worker and options.","ref":"HareMq.DynamicSupervisor.html#start_child/1","title":"HareMq.DynamicSupervisor.start_child/1","type":"function"},{"doc":"iex> HareMq.DynamicSupervisor.start_child(worker: MyApp.Consumer, name: :consumer1, opts: [config: %{}, consume: MyApp.Consumer])\n    {:ok, #PID<0.124.0>}","ref":"HareMq.DynamicSupervisor.html#start_child/1-examples","title":"Examples - HareMq.DynamicSupervisor.start_child/1","type":"function"},{"doc":"","ref":"HareMq.DynamicSupervisor.html#start_link/1","title":"HareMq.DynamicSupervisor.start_link/1","type":"function"},{"doc":"Module providing functions for managing RabbitMQ exchanges.\n\nThis module includes functions for declaring and binding exchanges.","ref":"HareMq.Exchange.html","title":"HareMq.Exchange","type":"module"},{"doc":"Bind a RabbitMQ exchange to a destination.","ref":"HareMq.Exchange.html#bind/1","title":"HareMq.Exchange.bind/1","type":"function"},{"doc":"- `:channel`: The AMQP channel.\n- `:destination`: The name of the destination exchange or queue.\n- `:source`: The name of the source exchange.\n- `:routing_key`: The routing key.","ref":"HareMq.Exchange.html#bind/1-parameters","title":"Parameters - HareMq.Exchange.bind/1","type":"function"},{"doc":"HareMq.Exchange.bind(channel: channel, destination: \"destination_exchange\", source: \"my_exchange\", routing_key: \"my_routing_key\")","ref":"HareMq.Exchange.html#bind/1-examples","title":"Examples - HareMq.Exchange.bind/1","type":"function"},{"doc":"Declare a RabbitMQ exchange.","ref":"HareMq.Exchange.html#declare/1","title":"HareMq.Exchange.declare/1","type":"function"},{"doc":"- `:channel`: The AMQP channel.\n- `:name`: The name of the exchange.\n- `:type`: The type of the exchange.","ref":"HareMq.Exchange.html#declare/1-parameters","title":"Parameters - HareMq.Exchange.declare/1","type":"function"},{"doc":"HareMq.Exchange.declare(channel: channel, name: \"my_exchange\", type: :direct)\n    HareMq.Exchange.declare(channel: channel, name: \"my_exchange\")","ref":"HareMq.Exchange.html#declare/1-examples","title":"Examples - HareMq.Exchange.declare/1","type":"function"},{"doc":"GenServer module implementing a RabbitMQ message publisher.\n\nThis module provides a behavior for publishing messages to RabbitMQ, including connecting to RabbitMQ, declaring exchanges, and sending messages.","ref":"HareMq.Publisher.html","title":"HareMq.Publisher","type":"module"},{"doc":"","ref":"HareMq.Publisher.Behaviour.html","title":"HareMq.Publisher.Behaviour","type":"behaviour"},{"doc":"","ref":"HareMq.Publisher.Behaviour.html#c:publish_message/1","title":"HareMq.Publisher.Behaviour.publish_message/1","type":"callback"},{"doc":"Module providing functions for managing RabbitMQ queues.\n\nThis module includes functions for declaring queues and binding them to exchanges.","ref":"HareMq.Queue.html","title":"HareMq.Queue","type":"module"},{"doc":"Bind a queue to an exchange with the specified routing key.","ref":"HareMq.Queue.html#bind/1","title":"HareMq.Queue.bind/1","type":"function"},{"doc":"- `config`: A `%Configuration{}` struct containing queue configuration.","ref":"HareMq.Queue.html#bind/1-parameters","title":"Parameters - HareMq.Queue.bind/1","type":"function"},{"doc":"HareMq.Queue.bind(%Configuration{channel: channel, queue_name: \"my_queue\", exchange: \"my_exchange\", routing_key: \"my_routing_key\"})","ref":"HareMq.Queue.html#bind/1-examples","title":"Examples - HareMq.Queue.bind/1","type":"function"},{"doc":"Declare a durable RabbitMQ dead letter queue with specified options.","ref":"HareMq.Queue.html#declare_dead_queue/1","title":"HareMq.Queue.declare_dead_queue/1","type":"function"},{"doc":"- `config`: A `%Configuration{}` struct containing queue configuration.","ref":"HareMq.Queue.html#declare_dead_queue/1-parameters","title":"Parameters - HareMq.Queue.declare_dead_queue/1","type":"function"},{"doc":"HareMq.Queue.declare_dead_queue(%Configuration{channel: channel, dead_queue_name: \"my_queue.dead\", message_ttl: 3600000})","ref":"HareMq.Queue.html#declare_dead_queue/1-examples","title":"Examples - HareMq.Queue.declare_dead_queue/1","type":"function"},{"doc":"Declare a durable RabbitMQ delay queue with specified options.","ref":"HareMq.Queue.html#declare_delay_queue/1","title":"HareMq.Queue.declare_delay_queue/1","type":"function"},{"doc":"- `config`: A `%Configuration{}` struct containing queue configuration.","ref":"HareMq.Queue.html#declare_delay_queue/1-parameters","title":"Parameters - HareMq.Queue.declare_delay_queue/1","type":"function"},{"doc":"HareMq.Queue.declare_delay_queue(%Configuration{channel: channel, delay_queue_name: \"my_queue.delay\", exchange: \"my_exchange\", routing_key: \"my_routing_key\", delay_in_ms: 5000})","ref":"HareMq.Queue.html#declare_delay_queue/1-examples","title":"Examples - HareMq.Queue.declare_delay_queue/1","type":"function"},{"doc":"Declare a durable RabbitMQ queue.","ref":"HareMq.Queue.html#declare_queue/1","title":"HareMq.Queue.declare_queue/1","type":"function"},{"doc":"- `config`: A `%Configuration{}` struct containing queue configuration.","ref":"HareMq.Queue.html#declare_queue/1-parameters","title":"Parameters - HareMq.Queue.declare_queue/1","type":"function"},{"doc":"HareMq.Queue.declare_queue(%Configuration{channel: channel, queue_name: \"my_queue\", durable: true})","ref":"HareMq.Queue.html#declare_queue/1-examples","title":"Examples - HareMq.Queue.declare_queue/1","type":"function"},{"doc":"Module providing functions for republishing messages with retry handling.\n\nThis module includes functions for determining retry count, republishing to delay queues, and handling retries.","ref":"HareMq.RetryPublisher.html","title":"HareMq.RetryPublisher","type":"module"},{"doc":"Republish a message to either a delay or dead letter queue based on the retry count.","ref":"HareMq.RetryPublisher.html#republish/3","title":"HareMq.RetryPublisher.republish/3","type":"function"},{"doc":"- `payload`: The message payload.\n- `configuration`: A `%Configuration{}` struct containing queue configuration.\n- `metadata`: Message metadata.","ref":"HareMq.RetryPublisher.html#republish/3-parameters","title":"Parameters - HareMq.RetryPublisher.republish/3","type":"function"},{"doc":"HareMq.RetryPublisher.republish(payload, configuration, metadata)","ref":"HareMq.RetryPublisher.html#republish/3-examples","title":"Examples - HareMq.RetryPublisher.republish/3","type":"function"},{"doc":"Republish a specified number of dead messages from the dead letter queue.","ref":"HareMq.RetryPublisher.html#republish_dead_messages/2","title":"HareMq.RetryPublisher.republish_dead_messages/2","type":"function"},{"doc":"- `configuration`: A `%Configuration{}` struct containing queue configuration.\n- `count`: The number of dead messages to republish.","ref":"HareMq.RetryPublisher.html#republish_dead_messages/2-parameters","title":"Parameters - HareMq.RetryPublisher.republish_dead_messages/2","type":"function"},{"doc":"HareMq.RetryPublisher.republish_dead_messages(configuration, 5)","ref":"HareMq.RetryPublisher.html#republish_dead_messages/2-examples","title":"Examples - HareMq.RetryPublisher.republish_dead_messages/2","type":"function"},{"doc":"Determine the retry count from message headers.","ref":"HareMq.RetryPublisher.html#retry_count/1","title":"HareMq.RetryPublisher.retry_count/1","type":"function"},{"doc":"- `headers`: Message headers.","ref":"HareMq.RetryPublisher.html#retry_count/1-parameters","title":"Parameters - HareMq.RetryPublisher.retry_count/1","type":"function"},{"doc":"retry_count = HareMq.RetryPublisher.retry_count(headers)","ref":"HareMq.RetryPublisher.html#retry_count/1-examples","title":"Examples - HareMq.RetryPublisher.retry_count/1","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html","title":"HareMq.Worker.Consumer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"HareMq.Worker.Consumer.html#child_spec/1","title":"HareMq.Worker.Consumer.child_spec/1","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html#declare_queues/1","title":"HareMq.Worker.Consumer.declare_queues/1","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html#get_channel/1","title":"HareMq.Worker.Consumer.get_channel/1","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html#init/1","title":"HareMq.Worker.Consumer.init/1","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html#republish_dead_messages/2","title":"HareMq.Worker.Consumer.republish_dead_messages/2","type":"function"},{"doc":"","ref":"HareMq.Worker.Consumer.html#start_link/1","title":"HareMq.Worker.Consumer.start_link/1","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}